==> CRM64Pro-0.14.0-docs.zip: CRM64Pro-0.14.0-docs/html/group___font_m.js <==
var group___font_m =
[
    [ "CRM64Pro::Font", "class_c_r_m64_pro_1_1_font.html", [
      [ "info", "class_c_r_m64_pro_1_1_font.html#a99eab2a87b6cfef1410d7c07b97721d6", null ],
      [ "getName", "class_c_r_m64_pro_1_1_font.html#a62df92b75ea23ff5e7a9dad48068f7ce", null ],
      [ "getID", "class_c_r_m64_pro_1_1_font.html#aff606d35454c27fe69b317542aae5f12", null ],
      [ "assignImage", "class_c_r_m64_pro_1_1_font.html#a60c29ada3a983c7d7ec57e303774d220", null ],
      [ "getImage", "class_c_r_m64_pro_1_1_font.html#a0fd73a3a80182c5ed470cf2cf52afe70", null ],
      [ "setCursor", "class_c_r_m64_pro_1_1_font.html#ab2a024f7eeed6c5353f3b7e737ed87c8", null ],
      [ "getCursor", "class_c_r_m64_pro_1_1_font.html#a9a7ba7c8c9448705f197f96b2bbcdb0c", null ],
      [ "getCursorPositionByPixel", "class_c_r_m64_pro_1_1_font.html#ac38aea8ffd7ca29c6f4f89d1407fe4ab", null ],
      [ "setKerning", "class_c_r_m64_pro_1_1_font.html#a8df694a505322a6099e2a44f44aff1cf", null ],
      [ "getKerning", "class_c_r_m64_pro_1_1_font.html#aef95a294c6117a226fe6ee4384663160", null ],
      [ "getWidth", "class_c_r_m64_pro_1_1_font.html#aae6a558d116977f0eb4a96e786f03f6f", null ],
      [ "getHeight", "class_c_r_m64_pro_1_1_font.html#a100d20d138fc16d0c04880e697f9888c", null ],
      [ "setPosition", "class_c_r_m64_pro_1_1_font.html#a1de13e229f62fae6be9813ecc9326bfb", null ],
      [ "getPositionX", "class_c_r_m64_pro_1_1_font.html#ac11a0fb3741fcbe6c84dc282c839f989", null ],
      [ "getPositionY", "class_c_r_m64_pro_1_1_font.html#a2892e080251f9ca3645107d76d29d814", null ],
      [ "render", "class_c_r_m64_pro_1_1_font.html#a1999d47ed9d63408fc2cba460dfb9fe1", null ],
      [ "renderEx", "class_c_r_m64_pro_1_1_font.html#a70f71175aece998207a8f7de65b81ece", null ],
      [ "save", "class_c_r_m64_pro_1_1_font.html#a801b7739454a44d5062180451b66f93e", null ],
      [ "save", "class_c_r_m64_pro_1_1_font.html#a747136a15605d75ef5544e35aaba570c", null ]
    ] ],
    [ "CRM64Pro::FontMgr", "class_c_r_m64_pro_1_1_font_mgr.html", [
      [ "info", "class_c_r_m64_pro_1_1_font_mgr.html#a0acca2c2bf50cebf19808f211cf9f00f", null ],
      [ "create", "class_c_r_m64_pro_1_1_font_mgr.html#a8bace90e5b801cadd31064ad00037cce", null ],
      [ "close", "class_c_r_m64_pro_1_1_font_mgr.html#af69774d92a1cfe19a24990fd81f9f478", null ],
      [ "getCount", "class_c_r_m64_pro_1_1_font_mgr.html#a810f6c0d349d9d630d420dcc1d2ba7e1", null ],
      [ "setName", "class_c_r_m64_pro_1_1_font_mgr.html#a092e0e707732f4dad6cbe2472d0c9eb0", null ],
      [ "get", "class_c_r_m64_pro_1_1_font_mgr.html#a925c38b451154189fffd652f1a7e172d", null ],
      [ "child", "class_c_r_m64_pro_1_1_font_mgr.html#ad1801040bfef894aa738fbb7f84075bd", null ],
      [ "load", "class_c_r_m64_pro_1_1_font_mgr.html#aeb8d36eb96dae14b1ad82aa2dbbaddea", null ],
      [ "load", "class_c_r_m64_pro_1_1_font_mgr.html#a9ad42d03f5d1a74f32a23368c935c2d1", null ],
      [ "remove", "class_c_r_m64_pro_1_1_font_mgr.html#a3aa16e74c6f16f21129fec524407761f", null ],
      [ "exist", "class_c_r_m64_pro_1_1_font_mgr.html#ac61b3963b8fafbad91f55b5db5d6e51e", null ],
      [ "exist", "class_c_r_m64_pro_1_1_font_mgr.html#ab044d83df29b6016fdaf8edea7938933", null ]
    ] ]
];

==> CRM64Pro-0.15.0-docs.zip: CRM64Pro-0.15.0-docs/html/group___font_m.js <==
var group___font_m =
[
    [ "CRM64Pro::Font", "class_c_r_m64_pro_1_1_font.html", [
      [ "info", "class_c_r_m64_pro_1_1_font.html#a99eab2a87b6cfef1410d7c07b97721d6", null ],
      [ "getName", "class_c_r_m64_pro_1_1_font.html#a62df92b75ea23ff5e7a9dad48068f7ce", null ],
      [ "getID", "class_c_r_m64_pro_1_1_font.html#aff606d35454c27fe69b317542aae5f12", null ],
      [ "assignImage", "class_c_r_m64_pro_1_1_font.html#a60c29ada3a983c7d7ec57e303774d220", null ],
      [ "getImage", "class_c_r_m64_pro_1_1_font.html#a0fd73a3a80182c5ed470cf2cf52afe70", null ],
      [ "setCursor", "class_c_r_m64_pro_1_1_font.html#ab2a024f7eeed6c5353f3b7e737ed87c8", null ],
      [ "getCursor", "class_c_r_m64_pro_1_1_font.html#a9a7ba7c8c9448705f197f96b2bbcdb0c", null ],
      [ "getCursorPositionByPixel", "class_c_r_m64_pro_1_1_font.html#ac38aea8ffd7ca29c6f4f89d1407fe4ab", null ],
      [ "setKerning", "class_c_r_m64_pro_1_1_font.html#a8df694a505322a6099e2a44f44aff1cf", null ],
      [ "getKerning", "class_c_r_m64_pro_1_1_font.html#aef95a294c6117a226fe6ee4384663160", null ],
      [ "getWidth", "class_c_r_m64_pro_1_1_font.html#aae6a558d116977f0eb4a96e786f03f6f", null ],
      [ "getHeight", "class_c_r_m64_pro_1_1_font.html#a100d20d138fc16d0c04880e697f9888c", null ],
      [ "setPosition", "class_c_r_m64_pro_1_1_font.html#a1de13e229f62fae6be9813ecc9326bfb", null ],
      [ "getPositionX", "class_c_r_m64_pro_1_1_font.html#ac11a0fb3741fcbe6c84dc282c839f989", null ],
      [ "getPositionY", "class_c_r_m64_pro_1_1_font.html#a2892e080251f9ca3645107d76d29d814", null ],
      [ "render", "class_c_r_m64_pro_1_1_font.html#a1999d47ed9d63408fc2cba460dfb9fe1", null ],
      [ "renderEx", "class_c_r_m64_pro_1_1_font.html#a3dcf7cdff4b1570f7b0c15eec7713585", null ],
      [ "save", "class_c_r_m64_pro_1_1_font.html#a801b7739454a44d5062180451b66f93e", null ],
      [ "save", "class_c_r_m64_pro_1_1_font.html#a747136a15605d75ef5544e35aaba570c", null ]
    ] ],
    [ "CRM64Pro::FontMgr", "class_c_r_m64_pro_1_1_font_mgr.html", [
      [ "info", "class_c_r_m64_pro_1_1_font_mgr.html#a0acca2c2bf50cebf19808f211cf9f00f", null ],
      [ "create", "class_c_r_m64_pro_1_1_font_mgr.html#a8bace90e5b801cadd31064ad00037cce", null ],
      [ "close", "class_c_r_m64_pro_1_1_font_mgr.html#af69774d92a1cfe19a24990fd81f9f478", null ],
      [ "getCount", "class_c_r_m64_pro_1_1_font_mgr.html#a810f6c0d349d9d630d420dcc1d2ba7e1", null ],
      [ "setName", "class_c_r_m64_pro_1_1_font_mgr.html#a092e0e707732f4dad6cbe2472d0c9eb0", null ],
      [ "get", "class_c_r_m64_pro_1_1_font_mgr.html#a925c38b451154189fffd652f1a7e172d", null ],
      [ "child", "class_c_r_m64_pro_1_1_font_mgr.html#ad1801040bfef894aa738fbb7f84075bd", null ],
      [ "load", "class_c_r_m64_pro_1_1_font_mgr.html#aeb8d36eb96dae14b1ad82aa2dbbaddea", null ],
      [ "load", "class_c_r_m64_pro_1_1_font_mgr.html#a9ad42d03f5d1a74f32a23368c935c2d1", null ],
      [ "loadFromBuffer", "class_c_r_m64_pro_1_1_font_mgr.html#a95fe3626686bdd5eb3a95f24532579da", null ],
      [ "remove", "class_c_r_m64_pro_1_1_font_mgr.html#a3aa16e74c6f16f21129fec524407761f", null ],
      [ "exist", "class_c_r_m64_pro_1_1_font_mgr.html#ac61b3963b8fafbad91f55b5db5d6e51e", null ],
      [ "exist", "class_c_r_m64_pro_1_1_font_mgr.html#ab044d83df29b6016fdaf8edea7938933", null ]
    ] ]
];
